## Dynamic PDF Example: Shipping Label with Bar Code

In this example, address data come from this HTML form, but they can easily come from an automated order processing system instead. For simple form applications like this, you can draw everything programmatically without much effort. Automatic invoice generation, for example, is only marginally different from this example. Then, you can forget about merging PDF and FDF for the form and fields. For more complex dynamic forms, see our 1040 Tax Form example.

107-line C source code for this CGI.

Please enter correct addresses for the "From" and "Ship To" fields, and a Tracking number (digits or upper-case alphabets only).

From:
Hunny Factory, Inc. 3442 Beehive Ave. Sydney 2342-897 Australia Telephone: 2342-23-9877

Ship To:
Mr. Pooh Bear 3456 Hunny Street Thousand Acre Woods, MA 23456 U.S.A. Telephone: (123) 456-7890

Airbill or Tracking Number:

To generate shipping label, press this button: .